Autocomplete-Light: Extremely Lightweight Autocomplete Web Component

## autocomplete-light input

A simple input which emits an event when the user selects an item and nothing more, check teh HTML source for usage.

This is the core autocompletion component, it's all about displaying a box with HTML fetched from the server, this is useful as-is to make a global navigation input like in the top bar of facebook for example, or to build other more complex components such as autocomplete-select.

## autocomplete-select non-multiple

An autocomplete-select is composed of a hidden select field maintained by the Web Component, a deck of visible choices that the user can remove, and an autocomplete input of course.

aab

## autocomplete-select multiple

Same as above, with multiple choices

aaa
bbb

## autocomplete-select from options

Local: it gets its options from introspecting the select tag without a url.

Change event on vanilla select also works

## form submission

Click this button to display form data in GET

## works inside small modals

WARNING: crashes safari

Click here to open modal